@@ -25,7 +25,6 @@ DJANGO_MODULES = [
     'split_at_breakpoints',
     'standard_deviation',
     'summary_stats',
-    'variation_coefficient',
 ]
 __all__ = DJANGO_MODULES
 
@@ -53,7 +52,6 @@ from .range import range
 from .split_at_breakpoints import split_at_breakpoints
 from .standard_deviation import standard_deviation
 from .summary_stats import summary_stats
-from .variation_coefficient import variation_coefficient
 
 # Test whether Django is installed
 try:
@@ -107,9 +105,10 @@ if HAS_DJANGO and HAS_GEODJANGO:
         'mean_center',
         'nudge_points',
         'standard_deviation_distance',
-        'variation_coefficient',
+        'standard_deviation_ellipses',
     ]
     from .random_point import random_point
     from .mean_center import mean_center
     from .nudge_points import nudge_points
     from .standard_deviation_distance import standard_deviation_distance
+    from .standard_deviation_ellipses import standard_deviation_ellipses
